#!/usr/bin/env bash

function help() {
  echo "./deploy.sh <cluster_id> <master_public_ip>"
  echo "Options:"
  echo "  cluster_id            cluster id"
  echo "  master_public_ip      master public ip"
  echo "  private_key           private_key"
}

here=$(cd `dirname $0`;pwd)
mkdir -p $here/.emr-tmp
export EMR_TEMP_DIR=$here/.emr-tmp

if [ $# -ne 3 ] || [ "$1" == "-h" ];then
  help
  exit 2
fi

function init_ansible() {
  export ANSIBLE_CONFIG=$here/ansible/ansible.cfg
  wget -c --tries=10  http://cnbj1-fds.api.xiaomi.net/emr/ansible_2.0.tar.gz -O ansible_2.0.tar.gz -O $EMR_TEMP_DIR/ansible_2.0.tar.gz
  tar -xzf $EMR_TEMP_DIR/ansible_2.0.tar.gz -C $EMR_TEMP_DIR

  source $EMR_TEMP_DIR/ansible/hacking/env-setup
}

cluster_id=$1
master_public_ip=$2
private_key=$3

shift 3

echo "[emr-master]" > $here/.emr-tmp/emr-master.host
echo "$master_public_ip" >> $here/.emr-tmp/emr-master.host

export DEPLOY_HELPER_HOME="/home/hadoop/app/emr-master/$cluster_id/emr-master/9002/deploy-helper"
export PACKAGE_SOURCE_PATH=${PACKAGE_SOURCE_PATH:-"$here/target/hive-fds-extends-1.0-SNAPSHOT.jar"}

init_ansible

ansible-playbook -i $here/.emr-tmp/emr-master.host $here/ansible/playbooks/deploy.yaml --private-key=${private_key} "$@" \
  -e "CLUSTER=$cluster_id" \
  -e "DEPLOY_HELPER_HOME=${DEPLOY_HELPER_HOME}" \
  -e "PACKAGE_SOURCE_PATH=${PACKAGE_SOURCE_PATH}" -vvv
